@@ -3,7 +3,7 @@ extern crate r2d2_odbc;
 
 use crate::{DB_PROPERTIES};
 use r2d2_odbc::ODBCConnectionManager;
-use r2d2::{Pool, PooledConnection, Error};
+use r2d2::{Pool, PooledConnection};
 use parking_lot::{ RwLock};
 use std::time::Duration;
 
